@@ -58,7 +58,7 @@ public:
 
 public slots:
 
-    void saveConfig()
+    void saveConfig() Q_DECL_OVERRIDE
     {
         AcpidConfiguration *acpidConfiguration = Globals::instance()
                                                      .findLogMode(QStringLiteral(ACPID_LOG_MODE_ID))
@@ -67,7 +67,7 @@ public slots:
         acpidConfiguration->setAcpidPaths(fileList->paths());
     }
 
-    void readConfig()
+    void readConfig() Q_DECL_OVERRIDE
     {
         AcpidConfiguration *acpidConfiguration = Globals::instance()
                                                      .findLogMode(QStringLiteral(ACPID_LOG_MODE_ID))
@@ -78,14 +78,14 @@ public slots:
         fileList->addPaths(acpidConfiguration->acpidPaths());
     }
 
-    void defaultConfig()
+    void defaultConfig() Q_DECL_OVERRIDE
     {
         // TODO Find a way to read the configuration per default
         readConfig();
     }
 
 protected:
-    bool isValid() const
+    bool isValid() const Q_DECL_OVERRIDE
     {
         if (fileList->isEmpty() == false) {
             return true;
