@@ -64,7 +64,7 @@ public:
 
 public slots:
 
-    void saveConfig()
+    void saveConfig() Q_DECL_OVERRIDE
     {
         logDebug() << "Saving config from Apache Options...";
 
@@ -75,13 +75,13 @@ public slots:
         apacheConfiguration->setApacheAccessPaths(apacheFileList->paths(apacheAccessPathsId));
     }
 
-    void defaultConfig()
+    void defaultConfig() Q_DECL_OVERRIDE
     {
         // TODO Find a way to read the configuration per default
         readConfig();
     }
 
-    void readConfig()
+    void readConfig() Q_DECL_OVERRIDE
     {
         ApacheConfiguration *apacheConfiguration = Globals::instance()
                                                        .findLogMode(QStringLiteral(APACHE_LOG_MODE_ID))
@@ -94,7 +94,7 @@ public slots:
     }
 
 protected:
-    bool isValid() const
+    bool isValid() const Q_DECL_OVERRIDE
     {
         if (apacheFileList->isOneOfCategoryEmpty() == true) {
             logDebug() << "Apache configuration not valid";
