@@ -41,7 +41,7 @@ public:
 
     virtual ~CronItemBuilder() {}
 
-    QString createFormattedText(LogLine *line) const
+    QString createFormattedText(LogLine *line) const Q_DECL_OVERRIDE
     {
         QString result;
 
