@@ -52,9 +52,9 @@ public:
 
     ~SambaLogMode();
 
-    Analyzer *createAnalyzer(const QVariant &options = QVariant());
+    Analyzer *createAnalyzer(const QVariant &options = QVariant()) Q_DECL_OVERRIDE;
 
-    QList<LogFile> createLogFiles();
+    QList<LogFile> createLogFiles() Q_DECL_OVERRIDE;
 };
 
 #endif // _SAMBA_LOG_MODE_H_
