@@ -83,7 +83,7 @@ public:
 
 public slots:
 
-    void saveConfig()
+    void saveConfig() Q_DECL_OVERRIDE
     {
         XSessionConfiguration *configuration = Globals::instance()
                                                    .findLogMode(QStringLiteral(X_SESSION_LOG_MODE_ID))
@@ -93,7 +93,7 @@ public slots:
         configuration->setIgnoreXorgErrors(ignoreXorgErrors->isChecked());
     }
 
-    void readConfig()
+    void readConfig() Q_DECL_OVERRIDE
     {
         XSessionConfiguration *configuration = Globals::instance()
                                                    .findLogMode(QStringLiteral(X_SESSION_LOG_MODE_ID))
@@ -109,14 +109,14 @@ public slots:
         prepareXorgErrorsDescription();
     }
 
-    void defaultConfig()
+    void defaultConfig() Q_DECL_OVERRIDE
     {
         // TODO Find a way to read the configuration per default
         readConfig();
     }
 
 protected:
-    bool isValid() const
+    bool isValid() const Q_DECL_OVERRIDE
     {
         if (xsessionUrlRequester->url().path().isEmpty() == false) {
             return true;
